<?php
namespace Teknisa\SM\Controller;

use Teknisa\SM\Service\Sm00005000ParametrizacoesServicesService;
use Teknisa\SM\Controller\SMCrud;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Teknisa\SM\Service\SmParceiroNegocioService;
use Zeedhi\Framework\DataSource\DataSet;

class SmParceiroNegocio extends SMCrud{
    protected $crudService;
    protected $dataSourceName = 'parcnegocio_parceria_hierarquia';
    protected $parametrogeral;
    protected $parceiroService;

    public function __construct($crudService, $environment, Sm00005000ParametrizacoesServicesService $parametrogeral, SmParceiroNegocioService $parceiroService) {
        parent::__construct($crudService, $environment);
        $this->parametrogeral   = $parametrogeral;
        $this->parceiroService  = $parceiroService;
    }
    
    /**
     * Busca os dados do parceiro adicionando o filtro por 
     * operador responsavel para a hierarquia de operadores
    **/
    public function find(Request\Filter $request, Response $response){
        try{
            $nrorg = $this->environment->getNrOrg();
            $idUtilizaOper = $this->parametrogeral->getIdUtilizaHierarquiaOper($nrorg);
            if($idUtilizaOper == 'N')
                $this->dataSourceName = 'parcnegocio_parceria';
            else 
                $request->getFilterCriteria()->addCondition("P_CDOPERADOR", "=", $this->environment->getCdOperador());
                
            parent::find($request, $response);  
            $this->dataSourceName = 'parcnegocio_parceria_hierarquia';
        } catch(\Exception $e){
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function getPermissaoAlteracaoInscParceiro(Request\Row $request, Response $response){
        try{
            $row   = $request->getRow();
            $nrorg = $this->environment->getNrOrg();
            
            $nrparcnegocio    = $row["NRPARCNEGOCIO"];
            $permiteAlteracao = $this->parceiroService->getPermissaoAlteracaoInscParceiro($nrparcnegocio, $nrorg);
            
            $response->addDataSet(new DataSet("parcnegocio", array("PERMITEALTSM" => $permiteAlteracao)));
        } catch(\Exception $e){
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function alterarInscricaoParceiro(Request\Row $request, Response $response){
        try{
            $row      = $request->getRow();
            $nrorg    = $this->environment->getNrOrg();
            $operador = $this->environment->getCdOperador();
            
            $nrparcnegocio    = $row["NRPARCNEGOCIO"];
            $nrnewinscricao   = $row["NRNEWINSCRICAO"];
            $nroldinscricao   = $row["NROLDINSCRICAO"];
            $nmprincipalparc  = $row["NMPRINCIPALPARC"];
            $nmsecundarioparc = $row["NMSECUNDARIPARC"];
            $dsjustificativa  = $row["DSJUSTIFICATIVA"];
            $idinativaparc    = $row["IDINATIVAPARC"];
            $dscaminhoarq     = $row["DSCAMINHOARQ"];
            
            $this->parceiroService->alterarInscricaoParceiro($nrparcnegocio, $nrnewinscricao, $nroldinscricao, $nmprincipalparc, $nmsecundarioparc, $dsjustificativa, $idinativaparc, $dscaminhoarq, $nrorg, $operador);
        } catch(\Exception $e){
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function getTermoAnuenciaParceiro(Request\Row $request, Response $response){
        try {
            $row   = $request->getRow();
            $nrorg = $this->environment->getNrOrg();
            
            $nrinscricao = $row["NRINSCRICAOPARC"];
            $documentos  = $this->parceiroService->getTermoAnuenciaParceiro($nrinscricao, $nrorg);
            $response->addDataSet(new DataSet("URLDOCUMENTO", array($documentos)));
        } catch(\Exception $e){
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
}